@@ -51,6 +51,12 @@ void reconnect()
 	if(mystate->reconnect == OER_RECONNECT_NONE) {
 		return;
 	}
+	/* this is a workaround for the situation where admin changes oer's
+	   nick to a taken one and then jumps/reconnects, oer should at least
+	   try to get the one the admin specified or fall back to alternative */
+	if(strcasecmp(mystate->nick, mystate->getnick)) {
+		strncpy(mystate->nick, mystate->getnick, NICKLEN);
+	}
 	switch(mystate->reconnect) {
 	case OER_RECONNECT_ADMIN:
 		snprintf(stringbuffer, WRITE_BUFFER_LENGTH, "QUIT :%s\n", mystate->signoff);
