@@ -166,6 +166,8 @@ enum WHICHCOMMAND_RETURN_VALUES {
 	OER_WHICHCOMMAND_DATE,
 	OER_WHICHCOMMAND_USERCOPY,
 	OER_WHICHCOMMAND_CLEARBANS,
+	OER_WHICHCOMMAND_CYCLE,
+	OER_WHICHCOMMAND_BSTATS,
 	OER_WHICHCOMMAND_INVALID
 };
 
@@ -254,7 +256,7 @@ enum OER_FLAGS_TYPE {
 };
 
 #define OER_FLAGS_GLOBAL "bdfglmpqs"
-#define OER_FLAGS_CHANNEL "!aAbcDefFGklLmMnNoOpPqrsSuUtTvVwx"
+#define OER_FLAGS_CHANNEL "!aAbcDefFGklLmMnNoOpPqrRsSuUtTvVwx"
 #define OER_FLAGS_ADMIN "dn"
 #define OER_FLAGS_USER "!adfmovrx"
 
@@ -355,7 +357,7 @@ enum OER_FLAGS_TYPE {
 #define OER_SERVER_IS_STONED "stoned server"
 #define OER_INTERNAL_DYNAMIC_ADMIN "*INTDYN*"
 #define OER_REALNAME "http://oer.equnet.org/help.html"
-#define OER_COPYRIGHT1 "oer version 1.0-52, Copyright (C) 2000-2002 EQU <equ@equnet.org>"
+#define OER_COPYRIGHT1 "oer version 1.0-53, Copyright (C) 2000-2002 EQU <equ@equnet.org>"
 #define OER_COPYRIGHT2 "oer comes with ABSOLUTELY NO WARRANTY; for details see the\n\
 GNU General Public License (COPYING) provided with this distribution.\n\
 This is free software, and you are welcome to redistribute it under\n\
@@ -577,6 +579,7 @@ struct channel {
 	time_t rejoin_at;
 	time_t last_quote;
 	time_t join_ts;
+	time_t requestop;
 	FILE *seen;
 	FILE *last;
 	struct join *joins;
